@@ -25,8 +25,6 @@
 
 typedef struct _static_surface {
 
-int number;
-
 /***********************************************************
  * scanning current state:                                 *
  * 1) save x,y,z,f coordinates and wavefunction per vertex *
@@ -60,7 +58,14 @@ int face_c[2][2][3];
 int a, b, c;
 double origin[3];
 char *above, *outside;
-int n_points, n_char, n_bit;
+int n_char, n_bit;
+
+/**************************************
+ * stack arrays, used to avoid        *
+ * recursive calls in static_outside; *
+ **************************************/
+
+unsigned char *stack_a, *stack_b, *stack_c;
 
 /********************************************
  * pointers to functions building triangles *
@@ -70,30 +75,29 @@ int n_points, n_char, n_bit;
 void (*f2d[16]) (struct _static_surface *surface, int *v0, int *v1, int *v2, int *v3);
 void (*f3d[16]) (struct _static_surface *surface, int *v0, int *v1, int *v2, int *v3);
 
-/********************************
- * save accuracy scanning data: *
- * 1) sampling cube width       *
- * 2) number of sampling cubes  *
- *    per octant per direction  *
- ********************************/
+/**************************************
+ * accuracy per octant per direction: *
+ * 1) width of sampling cubes         *
+ * 2) number of sampling cubes        *
+ * 3) number of sampling points       *
+ **************************************/
 
 double width;
-int slices;
+int slices, n_points;
 
-/***************************
- * save wave function data *
- ***************************/
+/**********************
+ * wave function data *
+ **********************/
 
 gamgi_radial function_r;
 gamgi_angular function_a;
 double constant, ho;
 
-/************************
- * save user input data *
- ************************/
+/****************
+ * orbital data *
+ ****************/
 
 gamgi_orbital *orbital;
-int *octants;
 
 /****************************************
  * save current triangle array position *
@@ -1019,7 +1023,7 @@ lines[offset++] = 3;
 lines[offset++] = 7;
 }
 
-gamgi_bool static_wired (gamgi_orbital *orbital, int *octants, int seed)
+gamgi_bool static_wired (gamgi_orbital *orbital)
 {
 gamgi_radial function_r;
 gamgi_angular function_a;
@@ -1044,7 +1048,6 @@ sampling = orbital->sampling;
 
 orbital->n_points = n_points = sampling + dots[0];
 orbital->points = points = (double *) malloc (n_points * 3 * sizeof (double));
-if (dots[0] > 0) static_frame (orbital);
 
 static_radial (orbital->n, orbital->l, &constant_r, &function_r);
 static_angular (orbital->l, orbital->m, &constant_a, &function_a);
@@ -1068,7 +1071,7 @@ offset_negative = n_points - 1;
  * set random number sequence *
  ******************************/
 
-srand (seed);
+srand (orbital->seed);
 
 /*******************************************
  * i_bad is just to prevent infinite loops *
@@ -1087,7 +1090,7 @@ while (i < sampling && bad < GAMGI_CHEM_ORBITAL_BAD)
   if (x > 0) a = 1;
   if (y > 0) b = 1;
   if (z > 0) c = 1;
-  if (octants[4*c + 2*b + a] == FALSE) continue;
+  if (orbital->octants[4*c + 2*b + a] == FALSE) continue;
 
   r = radius * sqrt (r);
   rho = r * ho;
@@ -1113,10 +1116,20 @@ while (i < sampling && bad < GAMGI_CHEM_ORBITAL_BAD)
  ***************************************/
  
 dots[1] = offset_positive - dots[0];
-if (dots[2] == TRUE) dots[2] = n_points - 1 - offset_negative;
-else dots[1] += n_points - 1 - offset_negative;
+if (orbital->phase == TRUE)
+  dots[2] = n_points - 1 - offset_negative;
+else
+  dots[1] += n_points - 1 - offset_negative;
+
 if (dots[0] + dots[1] + dots[2] == n_points) return TRUE;
 
+/*************************************
+ * clean memory when things go wrong *
+ *************************************/
+
+free (orbital->points);
+orbital->points = NULL;
+orbital->n_points = 0;
 return FALSE;
 }
 
@@ -1201,149 +1214,88 @@ for (c = 0; c < n_points; c++)
   }
 }
 
-void static_outside (char *outside, char *above, int n_points, int a, int b, int c)
+void static_outside (static_surface *surface, int a, int b, int c)
 {
-int bit;
+unsigned char *stack_a, *stack_b, *stack_c;
+char *outside, *above;
+int a_shift, b_shift, c_shift;
+int offset, step, bit, bit_new;
+int n_points;
 
-/****************
- * mark a faces *
- ****************/
+/*************************************************
+ * this function must be non-recursive, because  *
+ * the number of recursive calls is just too big *
+ *************************************************/
 
-if (a == 0 || a == n_points - 1)
+n_points = surface->n_points;
+outside = surface->outside;
+above = surface->above;
+
+stack_a = surface->stack_a;
+stack_b = surface->stack_b;
+stack_c = surface->stack_c;
+
+a_shift = 1;
+b_shift = n_points;
+c_shift = n_points * n_points;
+
+offset = -1;
+step = 0;
+
+while (1 > 0)
   {
-  if (b > 0)
+  /*********************
+   * controlling block *
+   *********************/
+
+  offset += step;
+  if (step == +1)
     {
-    bit = static_offset (n_points, a, b - 1, c);
-    if (BITTEST(outside, bit) == 0 && BITTEST(above, bit) == 0)
-      {
-      BITSET(outside, bit);
-      static_outside (outside, above, n_points, a, b - 1, c);
-      }
+    BITSET(outside, bit_new);
+    stack_a[offset] = a;
+    stack_b[offset] = b;
+    stack_c[offset] = c;
     }
-
-  if (b < n_points - 1)
+  if (step == -1)
     {
-    bit = static_offset (n_points, a, b + 1, c);
-    if (BITTEST(outside, bit) == 0 && BITTEST(above, bit) == 0)
-      {
-      BITSET(outside, bit);
-      static_outside (outside, above, n_points, a, b + 1, c);
-      }
+    if (offset < 0) break;
+    a = stack_a[offset];
+    b = stack_b[offset];
+    c = stack_c[offset];
     }
+  bit = a * a_shift + b * b_shift + c * c_shift;
 
-  if (c > 0)
-    {
-    bit = static_offset (n_points, a, b, c - 1);
-    if (BITTEST(outside, bit) == 0 && BITTEST(above, bit) == 0)
-      {
-      BITSET(outside, bit);
-      static_outside (outside, above, n_points, a, b, c - 1);
-      }
-    }
+  /******************
+   * scanning block *
+   ******************/
 
-  if (c < n_points - 1)
-    {
-    bit = static_offset (n_points, a, b, c + 1);
-    if (BITTEST(outside, bit) == 0 && BITTEST(above, bit) == 0)
-      {
-      BITSET(outside, bit);
-      static_outside (outside, above, n_points, a, b, c + 1);
-      }
-    }
-  }
+  step = +1;
 
-/****************
- * mark b faces *
- ****************/
+  bit_new = bit - a_shift;
+  if (a > 0 && BITTEST(outside, bit_new) == 0 &&
+  BITTEST(above, bit_new) == 0) { a--; continue; }
 
-if (b == 0 || b == n_points - 1)
-  {
-  if (a > 0)
-    {
-    bit = static_offset (n_points, a - 1, b, c);
-    if (BITTEST(outside, bit) == 0 && BITTEST(above, bit) == 0)
-      {
-      BITSET(outside, bit);
-      static_outside (outside, above, n_points, a - 1, b, c);
-      }
-    }
+  bit_new = bit + a_shift;
+  if (a < n_points - 1 && BITTEST(outside, bit_new) == 0 &&
+  BITTEST(above, bit_new) == 0) { a++; continue; }
 
-  if (a < n_points - 1)
-    {
-    bit = static_offset (n_points, a + 1, b, c);
-    if (BITTEST(outside, bit) == 0 && BITTEST(above, bit) == 0)
-      {
-      BITSET(outside, bit);
-      static_outside (outside, above, n_points, a + 1, b, c);
-      }
-    }
+  bit_new = bit - b_shift;
+  if (b > 0 && BITTEST(outside, bit_new) == 0 &&
+  BITTEST(above, bit_new) == 0) { b--; continue; }
 
-  if (c > 0)
-    {
-    bit = static_offset (n_points, a, b, c - 1);
-    if (BITTEST(outside, bit) == 0 && BITTEST(above, bit) == 0)
-      {
-      BITSET(outside, bit);
-      static_outside (outside, above, n_points, a, b, c - 1);
-      }
-    }
+  bit_new = bit + b_shift;
+  if (b < n_points - 1 && BITTEST(outside, bit_new) == 0 &&
+  BITTEST(above, bit_new) == 0) { b++; continue; }
 
-  if (c < n_points - 1)
-    {
-    bit = static_offset (n_points, a, b, c + 1);
-    if (BITTEST(outside, bit) == 0 && BITTEST(above, bit) == 0)
-      {
-      BITSET(outside, bit);
-      static_outside (outside, above, n_points, a, b, c + 1);
-      }
-    }
-  }
+  bit_new = bit - c_shift;
+  if (c > 0 && BITTEST(outside, bit_new) == 0 &&
+  BITTEST(above, bit_new) == 0) { c--; continue; }
 
-/****************
- * mark c faces *
- ****************/
+  bit_new = bit + c_shift;
+  if (c < n_points - 1 && BITTEST(outside, bit_new) == 0 &&
+  BITTEST(above, bit_new) == 0) { c++; continue; }
 
-if (c == 0 || c == n_points - 1)
-  {
-  if (a > 0)
-    {
-    bit = static_offset (n_points, a - 1, b, c);
-    if (BITTEST(outside, bit) == 0 && BITTEST(above, bit) == 0)
-      {
-      BITSET(outside, bit);
-      static_outside (outside, above, n_points, a - 1, b, c);
-      }
-    }
-
-  if (a < n_points - 1)
-    {
-    bit = static_offset (n_points, a + 1, b, c);
-    if (BITTEST(outside, bit) == 0 && BITTEST(above, bit) == 0)
-      {
-      BITSET(outside, bit);
-      static_outside (outside, above, n_points, a + 1, b, c);
-      }
-    }
-
-  if (b > 0)
-    {
-    bit = static_offset (n_points, a, b - 1, c);
-    if (BITTEST(outside, bit) == 0 && BITTEST(above, bit) == 0)
-      {
-      BITSET(outside, bit);
-      static_outside (outside, above, n_points, a, b - 1, c);
-      }
-    }
-
-  if (b < n_points - 1)
-    {
-    bit = static_offset (n_points, a, b + 1, c);
-    if (BITTEST(outside, bit) == 0 && BITTEST(above, bit) == 0)
-      {
-      BITSET(outside, bit);
-      static_outside (outside, above, n_points, a, b + 1, c);
-      }
-    }
+  step = -1;
   }
 }
 
@@ -2073,6 +2025,7 @@ bit = static_offset (n_points, a + v2[0], b + v2[1], c + v2[2]);
 if (BITTEST(outside, bit) == 0) state |= 4;
 bit = static_offset (n_points, a + v3[0], b + v3[1], c + v3[2]);
 if (BITTEST(outside, bit) == 0) state |= 8;
+
 (*surface->f2d[state]) (surface, v0, v1, v2, v3);
 }
 
@@ -2321,20 +2274,19 @@ for (b = 0; b < n_points - 1; b++)
   }
 }
 
-static static_surface *static_start (gamgi_orbital *orbital, int *octants)
+static static_surface *static_start (gamgi_orbital *orbital)
 {
 static_surface *surface;
 double constant_r, constant_a, constant_z, za;
 int n_points, n_bit, n_char;
 int a, b, c;
 
-/***********************************************
- * allocate main structure and user input data *
- ***********************************************/
+/***************************
+ * allocate main structure *
+ ***************************/
 
 surface = (static_surface *) malloc (sizeof (static_surface));
 surface->orbital = orbital;
-surface->octants = octants;
 
 /*************************
  * get orbital constants *
@@ -2342,6 +2294,7 @@ surface->octants = octants;
 
 static_radial (orbital->n, orbital->l, &constant_r, &surface->function_r);
 static_angular (orbital->l, orbital->m, &constant_a, &surface->function_a);
+
 za = orbital->charge / GAMGI_CHEM_A0;
 surface->ho = 2 * za / orbital->n;
 constant_z = pow (za, 1.5);
@@ -2364,6 +2317,14 @@ surface->n_char = n_char = BITNSLOTS(n_bit);
 surface->above = (char *) malloc (n_char * sizeof (char));
 surface->outside = (char *) malloc (n_char * sizeof (char));
 
+/*************************
+ * allocate stack arrays *
+ *************************/
+
+surface->stack_a = (unsigned char *) malloc (n_bit * sizeof (unsigned char));
+surface->stack_b = (unsigned char *) malloc (n_bit * sizeof (unsigned char));
+surface->stack_c = (unsigned char *) malloc (n_bit * sizeof (unsigned char));
+
 /************************************************************
  * Initialize, accumulate, how many times each octant face  *
  * will be rendered. When face = 0 the face does not exist, *
@@ -2379,10 +2340,8 @@ for (c = 0; c <= 1; c++)
       {
       surface->face_a[a + 0][b][c] = 0;
       surface->face_a[a + 1][b][c] = 0;
-
       surface->face_b[a][b + 0][c] = 0;
       surface->face_b[a][b + 1][c] = 0;
-
       surface->face_c[a][b][c + 0] = 0;
       surface->face_c[a][b][c + 1] = 0;
       }
@@ -2395,14 +2354,12 @@ for (c = 0; c <= 1; c++)
     {
     for (a = 0; a <= 1; a++)
       {
-      if (octants[4 * c + 2 * b + a] == TRUE)
+      if (orbital->octants[4 * c + 2 * b + a] == TRUE)
         {
         surface->face_a[a + 0][b][c]++;
         surface->face_a[a + 1][b][c]++;
-
         surface->face_b[a][b + 0][c]++;
         surface->face_b[a][b + 1][c]++;
-
         surface->face_c[a][b][c + 0]++;
         surface->face_c[a][b][c + 1]++;
         }
@@ -2450,24 +2407,29 @@ return surface;
 
 void static static_end (static_surface *surface)
 {
+free (surface->stack_a);
+free (surface->stack_b);
+free (surface->stack_c);
+
 free (surface->above);
 free (surface->outside);
+
 free (surface);
 }
 
-int static_solid (gamgi_orbital *orbital, int *octants)
+int static_solid (gamgi_orbital *orbital)
 {
 static_surface *surface;
 char *outside, *above;
 int *dots;
 int slices, n_points;
-int a, b, c, bit;
+int a, b, c;
 
 /*****************
  * allocate data *
  *****************/
 
-surface = static_start (orbital, octants);
+surface = static_start (orbital);
 
 /*************************
  * allocate points array *
@@ -2476,15 +2438,6 @@ surface = static_start (orbital, octants);
 orbital->n_points = GAMGI_CHEM_ORBITAL_SEGMENT;
 orbital->points  = (double *) malloc (orbital->n_points * 3 * sizeof (double));
 
-/******************
- * allocate frame *
- ******************/
-
-dots = orbital->dots;
-if (dots[0] > 0) static_frame (orbital);
-dots[1] = 0;
-dots[2] = 0;
-
 /*****************
  * build octants *
  *****************/
@@ -2500,26 +2453,19 @@ for (c = 0; c <= 1; c++)
     {
     for (a = 0; a <= 1; a++)
       {
-      if (octants[4 * c + 2 * b + a] == TRUE)
+      if (orbital->octants[4 * c + 2 * b + a] == TRUE)
         {
         static_clean (above, surface->n_char);
         static_above (surface, a, b, c);
 
         static_clean (outside, surface->n_char);
-        bit = static_offset (n_points, a * slices, b * slices, c * slices);
-        if (BITTEST(outside, bit) == 0 && BITTEST(above, bit) == 0)
-          {
-          BITSET(outside, bit);
-          static_outside (outside, above, n_points, a * slices, b * slices, c * slices);
-          }
+        static_outside (surface, a * slices, b * slices, c * slices);
 
         /******************************************
          * scan cubes to build orbital 3d surface *
          ******************************************/
 
-/*
         static_cubes (surface);
-*/
 
         /*************************************************************
          * scan squares to build octant faces a-, a+, b-, b+, c-, c+ *
@@ -2540,6 +2486,7 @@ for (c = 0; c <= 1; c++)
  * resize array *
  ****************/
 
+dots = orbital->dots;
 orbital->n_points = dots[0] + dots[1] + dots[2];
 orbital->points = (double *) realloc (orbital->points, orbital->n_points * 3 * sizeof (double));
 
@@ -2552,6 +2499,18 @@ static_end (surface);
 return TRUE;
 }
 
+gamgi_bool gamgi_chem_orbital_number (int n, int l, int m)
+{
+/*******************************************************
+ * accepted range so far for n [1,6], l [0,5], m[-5,5] *
+ *******************************************************/
+
+if (l > n - 1) return FALSE;
+if (m < -l || m > l) return FALSE;
+
+return TRUE;
+}
+
 void gamgi_chem_orbital_m (int l, gamgi_bool *sensitive)
 {
 switch (l)
@@ -2767,18 +2726,40 @@ for (r = r_max; r < GAMGI_CHEM_ORBITAL_MAX; r += GAMGI_CHEM_ORBITAL_STEP)
 return GAMGI_CHEM_ORBITAL_MAX;
 }
 
-gamgi_bool gamgi_chem_orbital_create (gamgi_orbital *orbital,
-int *octants, int seed)
+void gamgi_chem_orbital_name (int n0, int l0, int m0, char *token)
 {
-if (orbital->style == GAMGI_MESA_WIRED)
-  return static_wired (orbital, octants, seed);
+char *name[36] = {
+"s",
+"py", "pz", "px",
+"dxy", "dyz", "dz2", "dxz", "dx2_y2",
+"fy_3x2_y2", "fxyz", "fyz2", "fz3", "fxz2", "fz_x2_y2", "fx_x2_3y2",
+"gxy_x2_y2", "gzy3", "gz2_xy", "gz3y", "gz4", "gz3x", "gz2_x2_y2", "gzx3", "gx4_y4",
+"hy5", "hxyz_x2_y2", "hz2y3", "hz3_xy", "hz4y", "hz5", "hz4x", "hz3_x2_y2", "hz2x3", "hz_x4_y4", "hx5"};
+int l, m, offset = 0;
 
-if (orbital->style == GAMGI_MESA_SOLID)
-  return static_solid (orbital, octants);
+for (l = 0; l <= 5; l++)
+  {
+  for (m = -l; m <= l; m++)
+    {
+    if (l == l0 && m == m0)
+      { sprintf (token, "%d%s", n0, name[offset]); return; }
+    offset++;
+    }
+  }
 
-/*****************************************
- * control should never reach this point *
- *****************************************/
+sprintf (token, "Orbital");
+}
 
-return FALSE;
+gamgi_bool gamgi_chem_orbital_create (gamgi_orbital *orbital)
+{
+if (orbital->frame == TRUE) orbital->dots[0] = 8;
+
+if (orbital->style == GAMGI_MESA_WIRED && static_wired (orbital) == FALSE)
+  return FALSE;
+if (orbital->style == GAMGI_MESA_SOLID && static_solid (orbital) == FALSE)
+  return FALSE;
+
+if (orbital->frame == TRUE) static_frame (orbital);
+
+return TRUE;
 }
