@@ -104,6 +104,8 @@ gamgi_bool static_solid (gamgi_orbital *orbital, int *octants);
  * external functions *
  **********************/
 
+gamgi_bool gamgi_chem_orbital_number (int n, int l, int m);
+
 void gamgi_chem_orbital_m (int l, gamgi_bool *sensitive);
 
 void gamgi_chem_orbital_l (int n, gamgi_bool *sensitive);
@@ -112,8 +114,9 @@ int gamgi_chem_orbital_sampling (int n, int style);
 
 double gamgi_chem_orbital_radius (int n, int l, int m, double charge);
 
-gamgi_bool gamgi_chem_orbital_create (gamgi_orbital *orbital,
-int *octants, int seed);
+void gamgi_chem_orbital_name (int n0, int l0, int m0, char *token);
+
+gamgi_bool gamgi_chem_orbital_create (gamgi_orbital *orbital);
 
 /*************
  * Rationale *
