@@ -158,12 +158,22 @@ void (*draw) (struct _gamgi_orbital *);
 int n, l, m;
 double charge;
 
-/*****************
- * sampling data *
- *****************/
+/**************
+ * model data *
+ **************/
 
+gamgi_enum style;
 double radius, density;
-int sampling;
+int sampling, seed;
+
+/***************
+ * volume data *
+ ***************/
+
+gamgi_bool phase, frame;
+int octants[8];
+gamgi_bool axes;
+double length;
 
 /**************
  * array data *
@@ -174,19 +184,21 @@ double *points;
 int *lines;
 int n_points, n_lines;
 
-/*********************************
- * style, axes, colors, position *
- *********************************/
-
-gamgi_enum style;
-gamgi_bool axes;
-double length;
+/************
+ * position *
+ ************/
 
 double origin[3];
 double center[3];
 double quaternion[4];
 
-float base[3], phase[3], frame[3];
+/**********
+ * colors *
+ **********/
+
+float base_r, base_g, base_b;
+float phase_r, phase_g, phase_b;
+float frame_r, frame_g, frame_b;
 
 gamgi_dlist *text_start;
 gamgi_dlist *text_end;
