@@ -85,17 +85,38 @@ orbital_new->l = orbital->l;
 orbital_new->m = orbital->m;
 orbital_new->charge = orbital->charge;
 
+orbital_new->style = orbital->style;
 orbital_new->radius = orbital->radius;
 orbital_new->density = orbital->density;
 orbital_new->sampling = orbital->sampling;
+orbital_new->seed = orbital->seed;
+
+orbital_new->phase = orbital->phase;
+orbital_new->frame = orbital->frame;
+for (i = 0; i < 8; i++) orbital_new->octants[i] = orbital->octants[i];
+orbital_new->axes = orbital->axes;
+orbital_new->length = orbital->length;
+
+/******************************
+ * copy arrays: points, lines *
+ ******************************/
 
 orbital_new->dots[0] = orbital->dots[0];
 orbital_new->dots[1] = orbital->dots[1];
 orbital_new->dots[2] = orbital->dots[2];
 
-orbital_new->style = orbital->style;
-orbital_new->axes = orbital->axes;
-orbital_new->length = orbital->length;
+orbital_new->points = NULL;
+i = 3 * orbital->n_points;
+if (i != 0) orbital_new->points = (double *) malloc (sizeof (double) * i);
+while (i-- > 0) orbital_new->points[i] = orbital->points[i];
+
+orbital_new->lines = NULL;
+i = orbital->n_lines;
+if (i != 0) orbital_new->lines = (int *) malloc (sizeof (int) * i);
+while (i-- > 0) orbital_new->lines[i] = orbital->lines[i];
+
+orbital_new->n_points = orbital->n_points;
+orbital_new->n_lines = orbital->n_lines;
 
 /**************************************
  * copy position and orientation data *
@@ -114,38 +135,21 @@ orbital_new->quaternion[1] = orbital->quaternion[1];
 orbital_new->quaternion[2] = orbital->quaternion[2];
 orbital_new->quaternion[3] = orbital->quaternion[3];
 
-/******************************
- * copy arrays: points, lines *
- ******************************/
-
-orbital_new->points = NULL;
-i = 3 * orbital->n_points;
-if (i != 0) orbital_new->points = (double *) malloc (sizeof (double) * i);
-while (i-- > 0) orbital_new->points[i] = orbital->points[i];
-
-orbital_new->lines = NULL;
-i = orbital->n_lines;
-if (i != 0) orbital_new->lines = (int *) malloc (sizeof (int) * i);
-while (i-- > 0) orbital_new->lines[i] = orbital->lines[i];
-
-orbital_new->n_points = orbital->n_points;
-orbital_new->n_lines = orbital->n_lines;
-
 /**************************
  * copy color information *
  **************************/
 
-orbital_new->base[0] = orbital->base[0];
-orbital_new->base[1] = orbital->base[1];
-orbital_new->base[2] = orbital->base[2];
+orbital_new->base_r = orbital->base_r;
+orbital_new->base_g = orbital->base_g;
+orbital_new->base_b = orbital->base_b;
 
-orbital_new->phase[0] = orbital->phase[0];
-orbital_new->phase[1] = orbital->phase[1];
-orbital_new->phase[2] = orbital->phase[2];
+orbital_new->phase_r = orbital->phase_r;
+orbital_new->phase_g = orbital->phase_g;
+orbital_new->phase_b = orbital->phase_b;
 
-orbital_new->frame[0] = orbital->frame[0];
-orbital_new->frame[1] = orbital->frame[1];
-orbital_new->frame[2] = orbital->frame[2];
+orbital_new->frame_r = orbital->frame_r;
+orbital_new->frame_g = orbital->frame_g;
+orbital_new->frame_b = orbital->frame_b;
 }
 
 void gamgi_engine_copy_out_bond (gamgi_bond *bond, gamgi_bond *bond_new)
