@@ -91,6 +91,8 @@ text->font = FALSE;
 
 void gamgi_engine_start_orbital (gamgi_orbital *orbital)
 {
+int i;
+
 /*********************
  * initialise object *
  *********************/
@@ -109,9 +111,17 @@ orbital->l = 0;
 orbital->m = 0;
 orbital->charge = 0.0;
 
+orbital->style = FALSE;
 orbital->radius = 0.0;
 orbital->density = 0.0;
 orbital->sampling = 0;
+orbital->seed = 0;
+
+orbital->phase = FALSE;
+orbital->frame = FALSE;
+for (i = 0; i < 8; i++) orbital->octants[i] = 0;
+orbital->axes = FALSE;
+orbital->length = 0.0;
 
 orbital->dots[0] = 0;
 orbital->dots[1] = 0;
@@ -134,11 +144,6 @@ orbital->quaternion[0] = 0.0;
 orbital->quaternion[1] = 0.0;
 orbital->quaternion[2] = 0.0;
 orbital->quaternion[3] = 1.0;
-
-orbital->draw = NULL;
-orbital->style = FALSE;
-orbital->axes = FALSE;
-orbital->length = 0.0;
 }
 
 /**** external function *****
