@@ -29,6 +29,7 @@
 #include "gamgi_math_position.h"
 #include "gamgi_chem_atom.h"
 #include "gamgi_chem_bond.h"
+#include "gamgi_chem_orbital.h"
 #include "gamgi_phys_projection.h"
 #include "gamgi_phys_direction.h"
 #include "gamgi_expat_export.h"
@@ -162,7 +163,6 @@ text->font != gamgi->text->solid)
   gamgi_expat_export_attribute (fp, string, depth, column, error);
   }
 
-
 /*************************************
  * origin: x,y,z (optional, coupled) *
  *************************************/
@@ -232,6 +232,11 @@ void gamgi_expat_export_object_orbital (gamgi_orbital *orbital, FILE *fp,
 int depth, int *column, int *id, gamgi_bool *error)
 {
 char string[GAMGI_ENGINE_STRING];
+char token[GAMGI_ENGINE_TOKEN];
+
+double rotate[9], euler[3];
+double radius;
+int sampling, i;
 
 /*******************
  * name (optional) *
@@ -253,6 +258,183 @@ if (GAMGI_EXPAT_ID_ORBITAL == TRUE)
   gamgi_expat_export_attribute (fp, string, depth, column, error);
   }
 
+/****************************
+ * n,l,m numbers (required) *
+ ****************************/
+
+sprintf (string, "n=\"%d\"", orbital->n);
+gamgi_expat_export_attribute (fp, string, depth, column, error);
+sprintf (string, "l=\"%d\"", orbital->l);
+gamgi_expat_export_attribute (fp, string, depth, column, error);
+sprintf (string, "m=\"%d\"", orbital->m);
+gamgi_expat_export_attribute (fp, string, depth, column, error);
+
+/*********************
+ * charge (optional) *
+ *********************/
+
+if (fabs (orbital->charge - GAMGI_CHEM_ORBITAL_CHARGE) > GAMGI_MATH_TOLERANCE)
+  {
+  sprintf (string, "charge=\"%.*f\"", gamgi->gamgi->charge, orbital->charge);
+  gamgi_expat_export_attribute (fp, string, depth, column, error);
+  }
+
+/****************************************************
+ * style density, sampling, radius, seed (optional) *
+ ****************************************************/
+
+if (orbital->style != GAMGI_MESA_ORBITAL_STYLE)
+  {
+  if (orbital->style == GAMGI_MESA_WIRED)
+    sprintf (string, "style=\"wired\"");
+  if (orbital->style == GAMGI_MESA_SOLID)
+    sprintf (string, "style=\"solid\"");
+  gamgi_expat_export_attribute (fp, string, depth, column, error);
+  }
+
+if (fabs (orbital->density - GAMGI_CHEM_ORBITAL_DENSITY) > GAMGI_MATH_TOLERANCE)
+  {
+  sprintf (string, "%.*E", 1, orbital->density);
+  gamgi_expat_export_attribute (fp, string, depth, column, error);
+  }
+
+sampling = gamgi_chem_orbital_sampling (orbital->n, orbital->style);
+if (orbital->sampling != sampling)
+  {
+  sprintf (string, "sampling=\"%d\"", orbital->sampling);
+  gamgi_expat_export_attribute (fp, string, depth, column, error);
+  }
+
+radius = gamgi_chem_orbital_radius (orbital->n, orbital->l, orbital->m, orbital->charge);
+if (fabs (orbital->radius - radius) > GAMGI_MATH_TOLERANCE)
+  {
+  sprintf (string, "radius=\"%.*f\"", gamgi->gamgi->length, orbital->radius);
+  gamgi_expat_export_attribute (fp, string, depth, column, error);
+  }
+
+if (orbital->seed != GAMGI_MATH_SEED)
+  {
+  sprintf (string, "seed=\"%d\"", orbital->seed);
+  gamgi_expat_export_attribute (fp, string, depth, column, error);
+  }
+
+/******************************************
+ * phase, frame, octants, axes (optional) *
+ ******************************************/
+
+if (orbital->phase == FALSE)
+  gamgi_expat_export_attribute (fp, "phase=\"no\"", depth, column, error);
+
+if (orbital->frame == FALSE)
+  gamgi_expat_export_attribute (fp, "frame=\"no\"", depth, column, error);
+
+token[8] = '\0';
+for (i = 0; i < 8; i++) token[i] = (orbital->octants[i] == 0) ? '0' : '1';
+if (strcmp (token, "11111111") != 0)
+  {
+  sprintf (string, "octants=\"%s\"", token);
+  gamgi_expat_export_attribute (fp, string, depth, column, error);
+  }
+
+if (orbital->axes == TRUE)
+  {
+  sprintf (string, "length=\"%.*f\"", gamgi->gamgi->length, orbital->length);
+  gamgi_expat_export_attribute (fp, string, depth, column, error);
+  }
+
+/*************************************
+ * origin: x,y,z (optional, coupled) *
+ *************************************/
+
+if (fabs (orbital->origin[0] - 0.0) > GAMGI_MATH_TOLERANCE
+|| fabs (orbital->origin[1] - 0.0) > GAMGI_MATH_TOLERANCE
+|| fabs (orbital->origin[2] - 0.0) > GAMGI_MATH_TOLERANCE)
+  {
+  sprintf (string, "x=\"%.*f\"", gamgi->gamgi->length, orbital->origin[0]);
+  gamgi_expat_export_attribute (fp, string, depth, column, error);
+
+  sprintf (string, "y=\"%.*f\"", gamgi->gamgi->length, orbital->origin[1]);
+  gamgi_expat_export_attribute (fp, string, depth, column, error);
+
+  sprintf (string, "z=\"%.*f\"", gamgi->gamgi->length, orbital->origin[2]);
+  gamgi_expat_export_attribute (fp, string, depth, column, error);
+  }
+
+/**********************************************
+ * Euler angles: e1,e2,e3 (optional, coupled) *
+ **********************************************/
+
+gamgi_math_quaternion_to_matrix (orbital->quaternion, rotate);
+gamgi_math_euler_from_matrix (rotate, euler);
+
+if (fabs (euler[0] - 0.0) > GAMGI_MATH_TOLERANCE
+|| fabs (euler[1] - 0.0) > GAMGI_MATH_TOLERANCE
+|| fabs (euler[2] - 0.0) > GAMGI_MATH_TOLERANCE)
+  {
+  sprintf (string, "e1=\"%.*f\"", gamgi->gamgi->angle, euler[0]);
+  gamgi_expat_export_attribute (fp, string, depth, column, error);
+
+  sprintf (string, "e2=\"%.*f\"", gamgi->gamgi->angle, euler[1]);
+  gamgi_expat_export_attribute (fp, string, depth, column, error);
+
+  sprintf (string, "e3=\"%.*f\"", gamgi->gamgi->angle, euler[2]);
+  gamgi_expat_export_attribute (fp, string, depth, column, error);
+  }
+
+/*******************************************
+ * red,green,blue base (optional, coupled) *
+ *******************************************/
+
+if (fabs (orbital->base_r - GAMGI_MESA_ORBITAL_BASE_R) > GAMGI_MATH_TOLERANCE
+ || fabs (orbital->base_g - GAMGI_MESA_ORBITAL_BASE_G) > GAMGI_MATH_TOLERANCE
+ || fabs (orbital->base_b - GAMGI_MESA_ORBITAL_BASE_B) > GAMGI_MATH_TOLERANCE)
+  {
+  sprintf (string, "base_r=\"%.*f\"", GAMGI_MATH_DECIMAL_COLOR, orbital->base_r);
+  gamgi_expat_export_attribute (fp, string, depth, column, error);
+
+  sprintf (string, "base_g=\"%.*f\"", GAMGI_MATH_DECIMAL_COLOR, orbital->base_g);
+  gamgi_expat_export_attribute (fp, string, depth, column, error);
+
+  sprintf (string, "base_b=\"%.*f\"", GAMGI_MATH_DECIMAL_COLOR, orbital->base_b);
+  gamgi_expat_export_attribute (fp, string, depth, column, error);
+  }
+
+/********************************************
+ * red,green,blue phase (optional, coupled) *
+ ********************************************/
+
+if (fabs (orbital->phase_r - GAMGI_MESA_ORBITAL_PHASE_R) > GAMGI_MATH_TOLERANCE
+ || fabs (orbital->phase_g - GAMGI_MESA_ORBITAL_PHASE_G) > GAMGI_MATH_TOLERANCE
+ || fabs (orbital->phase_b - GAMGI_MESA_ORBITAL_PHASE_B) > GAMGI_MATH_TOLERANCE)
+  {
+  sprintf (string, "phase_r=\"%.*f\"", GAMGI_MATH_DECIMAL_COLOR, orbital->phase_r);
+  gamgi_expat_export_attribute (fp, string, depth, column, error);
+
+  sprintf (string, "phase_g=\"%.*f\"", GAMGI_MATH_DECIMAL_COLOR, orbital->phase_g);
+  gamgi_expat_export_attribute (fp, string, depth, column, error);
+
+  sprintf (string, "phase_b=\"%.*f\"", GAMGI_MATH_DECIMAL_COLOR, orbital->phase_b);
+  gamgi_expat_export_attribute (fp, string, depth, column, error);
+  }
+
+/********************************************
+ * red,green,blue frame (optional, coupled) *
+ ********************************************/
+ 
+if (fabs (orbital->frame_r - GAMGI_MESA_ORBITAL_FRAME_R) > GAMGI_MATH_TOLERANCE
+ || fabs (orbital->frame_g - GAMGI_MESA_ORBITAL_FRAME_G) > GAMGI_MATH_TOLERANCE
+ || fabs (orbital->frame_b - GAMGI_MESA_ORBITAL_FRAME_B) > GAMGI_MATH_TOLERANCE)
+  {
+  sprintf (string, "frame_r=\"%.*f\"", GAMGI_MATH_DECIMAL_COLOR, orbital->frame_r);
+  gamgi_expat_export_attribute (fp, string, depth, column, error);
+
+  sprintf (string, "frame_g=\"%.*f\"", GAMGI_MATH_DECIMAL_COLOR, orbital->frame_g);
+  gamgi_expat_export_attribute (fp, string, depth, column, error);
+
+  sprintf (string, "frame_b=\"%.*f\"", GAMGI_MATH_DECIMAL_COLOR, orbital->frame_b);
+  gamgi_expat_export_attribute (fp, string, depth, column, error);
+  }
+
 /********************
  * scale (optional) *
  ********************/
