@@ -2,7 +2,7 @@
  *
  * $GAMGI/src/gtk/orbital/gamgi_gtk_orbital_create.c
  *
- * Copyright (C) 2001, 2004 Carlos Pereira
+ * Copyright (C) 2013 Carlos Pereira
  *
  * Distributed under the terms of the GNU
  * General Public License: $GAMGI/LICENSE
@@ -29,8 +29,6 @@
 #include "gamgi_math_position.h"
 #include "gamgi_io_token.h"
 
-enum { STATIC_NONE = 0, STATIC_UNIT, STATIC_BOHR, STATIC_FRAME };
-
 static void static_phase (GtkWidget *widget, void *data)
 {
 gamgi_window *window = GAMGI_CAST_WINDOW data;
@@ -130,7 +128,7 @@ if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE)
    * update axes *
    ***************/
 
-  sensitive[STATIC_FRAME] = TRUE;
+  sensitive[GAMGI_CHEM_AXES_FRAME - 1] = TRUE;
   }
 else
   {
@@ -151,9 +149,9 @@ else
    ***************/
 
   axes = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
-  if (axes == STATIC_FRAME)
-    gtk_combo_box_set_active (GTK_COMBO_BOX (combo), STATIC_NONE);
-  sensitive[STATIC_FRAME] = FALSE;
+  if (axes == GAMGI_CHEM_AXES_FRAME - 1)
+    gtk_combo_box_set_active (GTK_COMBO_BOX (combo), GAMGI_CHEM_AXES_NONE - 1);
+  sensitive[GAMGI_CHEM_AXES_FRAME - 1] = FALSE;
   }
 }
 
@@ -178,7 +176,7 @@ label = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "label_length");
 combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_axes");
 axes = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
 
-if (axes == STATIC_NONE)
+if (axes == GAMGI_CHEM_AXES_NONE - 1)
   {
   gtk_widget_set_sensitive (entry, FALSE);
   gtk_widget_set_sensitive (label, FALSE);
@@ -188,11 +186,11 @@ else
   gtk_widget_set_sensitive (entry, TRUE);
   gtk_widget_set_sensitive (label, TRUE);
 
-  if (axes == STATIC_UNIT)
+  if (axes == GAMGI_CHEM_AXES_UNIT - 1)
     sprintf (token, "%.*f", gamgi->gamgi->length, 1.0);
-  if (axes == STATIC_BOHR)
+  if (axes == GAMGI_CHEM_AXES_BOHR - 1)
     sprintf (token, "%.*f", gamgi->gamgi->length, GAMGI_CHEM_A0);
-  if (axes == STATIC_FRAME && gamgi_io_token_double_scan (name,
+  if (axes == GAMGI_CHEM_AXES_FRAME - 1 && gamgi_io_token_double_scan (name,
   &radius, GAMGI_MATH_TOLERANCE_LENGTH, DBL_MAX) == TRUE)
     sprintf (token, "%.*f", gamgi->gamgi->length, 2.0 * radius);
   }
@@ -244,6 +242,14 @@ l = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
 combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_m");
 m = gtk_combo_box_get_active (GTK_COMBO_BOX (combo)) - 5;
 
+/********************
+ * set default name *
+ ********************/
+
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_orbital");
+gamgi_chem_orbital_name (n, l, m, token);
+gtk_entry_set_text (GTK_ENTRY (entry), token);
+
 /************************
  * set default sampling *
  ************************/
@@ -339,8 +345,7 @@ GtkWidget *button;
 GtkWidget *combo;
 const char *name;
 double origin[3], euler[3];
-int octants[8];
-int axes, seed;
+int axes;
 
 orbital = gamgi_engine_create_orbital ();
 gamgi_engine_start_orbital (orbital);
@@ -380,13 +385,22 @@ if (gamgi_io_token_double_scan (name,
   return;
   }
 
-/********************************************************************
- * Volume page: get style, sampling, radius, density, octants, axes *
- ********************************************************************/
+/**********************************************************
+ * Model page: get style, density, sampling, radius, seed *
+ **********************************************************/
 
 combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_style");
 orbital->style = 1 + gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
 
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_density");
+name = gtk_entry_get_text (GTK_ENTRY (entry));
+if (gamgi_io_token_double_scan (name, &orbital->density, 0.0, 1.0) == FALSE)
+  {
+  gamgi_gtk_dialog_message_create ("Error", "Invalid probability density threshold", window);
+  gamgi_engine_remove_orbital (orbital);
+  return;
+  }
+
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_sampling");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
 if (gamgi_io_token_int_scan (name, &orbital->sampling, 1, INT_MAX) == FALSE)
@@ -414,52 +428,39 @@ GAMGI_MATH_TOLERANCE_LENGTH, DBL_MAX) == FALSE)
   return;
   }
 
-entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_density");
-name = gtk_entry_get_text (GTK_ENTRY (entry));
-if (gamgi_io_token_double_scan (name, &orbital->density, 0.0, 1.0) == FALSE)
-  {
-  gamgi_gtk_dialog_message_create ("Error", "Invalid probability density threshold", window);
-  gamgi_engine_remove_orbital (orbital);
-  return;
-  }
-
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_seed");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
-if (gamgi_io_token_int_scan (name, &seed, 1, INT_MAX) == FALSE)
+if (gamgi_io_token_int_scan (name, &orbital->seed, 1, INT_MAX) == FALSE)
   {
   gamgi_gtk_dialog_message_create ("Error", "Invalid sampling seed", window);
   gamgi_engine_remove_orbital (orbital);
   return;
   }
 
-/***********
- * octants *
- ***********/
+/**********************************
+ * Volume page: get octants, axes *
+ **********************************/
 
 button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_1");
-octants[0] = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button));
+orbital->octants[0] = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button));
 button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_2");
-octants[1] = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button));
+orbital->octants[1] = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button));
 button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_3");
-octants[2] = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button));
+orbital->octants[2] = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button));
 button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_4");
-octants[3] = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button));
+orbital->octants[3] = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button));
 button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_5");
-octants[4] = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button));
+orbital->octants[4] = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button));
 button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_6");
-octants[5] = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button));
+orbital->octants[5] = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button));
 button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_7");
-octants[6] = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button));
+orbital->octants[6] = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button));
 button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_8");
-octants[7] = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button));
-
-/********
- * axes *
- ********/
+orbital->octants[7] = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button));
 
 combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_axes");
 axes = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
-if (axes != STATIC_NONE) orbital->axes = TRUE;
+if (axes != GAMGI_CHEM_AXES_NONE - 1) orbital->axes = TRUE;
 
 if (orbital->axes == TRUE)
   {
@@ -539,13 +540,13 @@ if (gamgi_io_token_double_scan (name, &euler[2], 0.0, 360.0) == FALSE)
   return;
   }
 
-/********************************************
- * View page: get Base, Phase, Frame colors *
- ********************************************/
+/************************************************************************
+ * View page: get 1) Base, Phase, Frame colors; 2) Phase, Frame buttons *
+ ************************************************************************/
 
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_base_red");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
-if (gamgi_io_token_float_scan (name, &orbital->base[0], 0.0, 1.0) == FALSE)
+if (gamgi_io_token_float_scan (name, &orbital->base_r, 0.0, 1.0) == FALSE)
   {
   gamgi_gtk_dialog_message_create ("Error", "Invalid base color", window);
   gamgi_engine_remove_orbital (orbital);
@@ -554,7 +555,7 @@ if (gamgi_io_token_float_scan (name, &orbital->base[0], 0.0, 1.0) == FALSE)
 
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_base_green");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
-if (gamgi_io_token_float_scan (name, &orbital->base[1], 0.0, 1.0) == FALSE)
+if (gamgi_io_token_float_scan (name, &orbital->base_g, 0.0, 1.0) == FALSE)
   {
   gamgi_gtk_dialog_message_create ("Error", "Invalid base color", window);
   gamgi_engine_remove_orbital (orbital);
@@ -563,7 +564,7 @@ if (gamgi_io_token_float_scan (name, &orbital->base[1], 0.0, 1.0) == FALSE)
 
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_base_blue");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
-if (gamgi_io_token_float_scan (name, &orbital->base[2], 0.0, 1.0) == FALSE)
+if (gamgi_io_token_float_scan (name, &orbital->base_b, 0.0, 1.0) == FALSE)
   {
   gamgi_gtk_dialog_message_create ("Error", "Invalid base color", window);
   gamgi_engine_remove_orbital (orbital);
@@ -573,16 +574,11 @@ if (gamgi_io_token_float_scan (name, &orbital->base[2], 0.0, 1.0) == FALSE)
 button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_phase");
 if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE)
   {
-  /********************************************
-   * signal that different colors will be use *
-   * for positive and negative orbital phase  *
-   ********************************************/
-
-  orbital->dots[2] = 1;
+  orbital->phase = TRUE;
 
   entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_phase_red");
   name = gtk_entry_get_text (GTK_ENTRY (entry));
-  if (gamgi_io_token_float_scan (name, &orbital->phase[0], 0.0, 1.0) == FALSE)
+  if (gamgi_io_token_float_scan (name, &orbital->phase_r, 0.0, 1.0) == FALSE)
     {
     gamgi_gtk_dialog_message_create ("Error", "Invalid phase color", window);
     gamgi_engine_remove_orbital (orbital);
@@ -591,7 +587,7 @@ if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE)
 
   entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_phase_green");
   name = gtk_entry_get_text (GTK_ENTRY (entry));
-  if (gamgi_io_token_float_scan (name, &orbital->phase[1], 0.0, 1.0) == FALSE)
+  if (gamgi_io_token_float_scan (name, &orbital->phase_g, 0.0, 1.0) == FALSE)
     {
     gamgi_gtk_dialog_message_create ("Error", "Invalid phase color", window);
     gamgi_engine_remove_orbital (orbital);
@@ -600,7 +596,7 @@ if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE)
 
   entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_phase_blue");
   name = gtk_entry_get_text (GTK_ENTRY (entry));
-  if (gamgi_io_token_float_scan (name, &orbital->phase[2], 0.0, 1.0) == FALSE)
+  if (gamgi_io_token_float_scan (name, &orbital->phase_b, 0.0, 1.0) == FALSE)
     {
     gamgi_gtk_dialog_message_create ("Error", "Invalid phase color", window);
     gamgi_engine_remove_orbital (orbital);
@@ -611,15 +607,11 @@ if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE)
 button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_frame");
 if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE)
   {
-  /******************************************************************
-   * signal that 8 additional points will be added to build a frame *
-   ******************************************************************/
-
-  orbital->dots[0] = 8;
+  orbital->frame = TRUE;
 
   entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_frame_red");
   name = gtk_entry_get_text (GTK_ENTRY (entry));
-  if (gamgi_io_token_float_scan (name, &orbital->frame[0], 0.0, 1.0) == FALSE)
+  if (gamgi_io_token_float_scan (name, &orbital->frame_r, 0.0, 1.0) == FALSE)
     {
     gamgi_gtk_dialog_message_create ("Error", "Invalid frame color", window);
     gamgi_engine_remove_orbital (orbital);
@@ -628,7 +620,7 @@ if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE)
 
   entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_frame_green");
   name = gtk_entry_get_text (GTK_ENTRY (entry));
-  if (gamgi_io_token_float_scan (name, &orbital->frame[1], 0.0, 1.0) == FALSE)
+  if (gamgi_io_token_float_scan (name, &orbital->frame_g, 0.0, 1.0) == FALSE)
     {
     gamgi_gtk_dialog_message_create ("Error", "Invalid frame color", window);
     gamgi_engine_remove_orbital (orbital);
@@ -637,7 +629,7 @@ if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE)
 
   entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_frame_blue");
   name = gtk_entry_get_text (GTK_ENTRY (entry));
-  if (gamgi_io_token_float_scan (name, &orbital->frame[2], 0.0, 1.0) == FALSE)
+  if (gamgi_io_token_float_scan (name, &orbital->frame_b, 0.0, 1.0) == FALSE)
     {
     gamgi_gtk_dialog_message_create ("Error", "Invalid frame color", window);
     gamgi_engine_remove_orbital (orbital);
@@ -669,11 +661,11 @@ gamgi_math_position_orbital_translation_set (orbital, origin);
 
 gamgi_gtk_history_update (window->layer, window->layer->undo, GAMGI_ENGINE_UNDO);
 
-/***************************************************************
- * return FALSE if unable to get the number of points required *
- ***************************************************************/
+/***************************************************************************
+ * Wired mode: return FALSE if unable to get the number of points required *
+ ***************************************************************************/
 
-if (gamgi_chem_orbital_create (orbital, octants, seed) == FALSE)
+if (gamgi_chem_orbital_create (orbital) == FALSE)
   {
   gamgi_gtk_dialog_message_create ("Error", "Invalid model data", window);
   gamgi_engine_remove_orbital (orbital);
@@ -709,7 +701,7 @@ combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_m");
 gtk_combo_box_set_active (GTK_COMBO_BOX (combo), 5);
 
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_charge");
-sprintf (token, "%.*f", gamgi->gamgi->charge, GAMGI_CHEM_CHARGE_Z);
+sprintf (token, "%.*f", gamgi->gamgi->charge, GAMGI_CHEM_ORBITAL_CHARGE);
 gtk_entry_set_text (GTK_ENTRY (entry), token);
 
 /********************
@@ -760,7 +752,7 @@ button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_8");
 gtk_button_clicked (GTK_BUTTON (button));
 
 combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_axes");
-gtk_combo_box_set_active (GTK_COMBO_BOX (combo), STATIC_NONE);
+gtk_combo_box_set_active (GTK_COMBO_BOX (combo), GAMGI_CHEM_AXES_NONE - 1);
 static_axes (NULL, window);
 
 /***********************
