@@ -2,7 +2,7 @@
  *
  * $GAMGI/src/gtk/orbital/gamgi_gtk_orbital_create.h
  *
- * Copyright (C) 2001, 2004 Carlos Pereira
+ * Copyright (C) 2013 Carlos Pereira
  *
  * Distributed under the terms of the GNU
  * General Public License: $GAMGI/LICENSE
@@ -13,10 +13,26 @@
  * internal functions *
  **********************
 
+static void static_phase (GtkWidget *widget, void *data);
+
+static void static_frame (GtkWidget *widget, void *data);
+
+static void static_axes (GtkWidget *widget, void *data);
+
+static void static_style (GtkWidget *widget, void *data);
+
+static void static_m (GtkWidget *widget, void *data);
+
+static void static_l (GtkWidget *widget, void *data);
+
+static void static_n (GtkWidget *widget, void *data);
+
 static void static_reset (gamgi_window *window);
 
 static void static_ok (GtkWidget *widget, void *data);
 
+static void static_init (gamgi_window *window);
+
  **********************
  * external functions *
  **********************/
@@ -30,7 +46,7 @@ void gamgi_gtk_orbital_create (GtkWidget *widget, void *data);
  * Rationale *
  *************
 
-Cleaned.
+Implemented: Nov 2012. Last update: May 2013.
 
  *************
  * Rationale *
