@@ -103,23 +103,23 @@ if (orbital->style == GAMGI_MESA_WIRED)
   {
   glLineWidth (4.0);
   if (dots[1] > 0)
-    { glColor3fv (orbital->base);
+    { glColor3f (orbital->base_r, orbital->base_g, orbital->base_b);
       gamgi_mesa_render_points (dots[1], orbital->points + 3 * dots[0]); }
   if (dots[2] > 0)
-    { glColor3fv (orbital->phase);
+    { glColor3f (orbital->phase_r, orbital->phase_g, orbital->phase_b);
       gamgi_mesa_render_points (dots[2], orbital->points + 3 * dots[0] + 3 * dots[1]); }
   glLineWidth (1.0);
   }
 else
   {
   glDisable (GL_CULL_FACE);
-  glColor3fv (orbital->base);
+  glColor3f (orbital->base_r, orbital->base_g, orbital->base_b);
   gamgi_mesa_render_triangles (dots[1] / 3, orbital->points + 3 * dots[0]);
   glEnable (GL_CULL_FACE);
   }
 
 if (dots[0] > 0)
-  { glColor3fv (orbital->frame);
+  { glColor3f (orbital->frame_r, orbital->frame_g, orbital->frame_b);
     gamgi_mesa_render_lines (orbital->lines, orbital->points); }
 if (orbital->axes == TRUE)
   gamgi_mesa_axes_orbital (orbital, TRUE);
