@@ -600,17 +600,8 @@ return FALSE;
 static gamgi_bool static_inside_triangles (gamgi_cell *cell, 
 int node, double *coord, int *index, int *triangles)
 {
-int row, plane;
 int x, y;
 
-/****************************************************
- *  row is the total number of nodes along a x row  *
- * plane is the total number of nodes in a xy plane *
- ****************************************************/
-
-row = 2*cell->n1 + cell->n2;
-plane = row * (2*cell->n2 + cell->n1);
-
 /********************
  * node coordinates *
  ********************/
